pub struct Config {
pub ip: [u8; 4],
pub port: u16,
pub database: String,
}Expand description
The application init configuration.
Fields
ip: [u8; 4]Defines what ip the web server will be bound to.
Default
If constructed with Default::default this value is set to [0, 0, 0, 0] (aka 0.0.0.0).
port: u16Defines what port the web server will listen to.
Default
If constructed with Default::default this value is set to 8901.
database: StringThe database connection URI.
Uses following format:
scheme://[username:password@]host[:port1][,...hostN[:portN]][/[database][?options]]Default
If constructed with Default::default this value is set to postgres://stry:stry@localhost:5432/stry.
Examples
Connecting to PostgreSQL:
postgres://stry:stry@localhost:5432/stryConnecting with SQLite:
sqlite://stry.dbWarning
The parser for this is very simple and may not be able to understand every valid URI.